@@ -1,6 +1,6 @@
 package swat;
 
-our $VERSION = 'v0.1.18';
+our $VERSION = 'v0.1.19';
 
 use base 'Exporter'; 
 
@@ -21,6 +21,7 @@ our $HTTP_RESPONSE;
 our ($curl_cmd, $content_file);
 our ($url, $path, $http_meth); 
 our ($debug, $ignore_http_err, $try_num, $debug_bytes);
+our ($is_swat_package);
 $| = 1;
 
 
@@ -102,7 +103,7 @@ sub check_line {
 
 sub header {
 
-    diag("start swat for $url/$path");
+    diag("start swat for $url/$path | is swat package $is_swat_package");
     diag("swat version $swat::VERSION | debug $debug | try num $try_num | ignore http errors $ignore_http_err")
 }
 
@@ -279,40 +280,36 @@ while dev guys or QA team ensure that deploy is fine and nothing breaks on the r
 So I need a B<tool to run smoke tests against web applications>. 
 Not tool only, but the way to B<create such a tests from the scratch in way easy and fast enough>. 
 
-So this how I came up with the idea of swat. If I was a marketing guy I'd say that swat:
+So this how I came up with the idea of swat. 
+
+
+=head1 Key features
+
+SWAT:
 
 =over
 
 =item *
 
-is easy to use and flexible tool to run smoke tests against web applications
-
+is very pragmatical tool designed for job to be done in a fast and simple way
 
 =item *
 
-is L<curl|http://curl.haxx.se/> powered and L<TAP|https://testanything.org/> compatible
+has simple and yet flexible DSL with low price mastering ( see my tutorial )
 
 =item *
 
-leverages famous L<prove|http://search.cpan.org/perldoc?prove> utility
+produces L<TAP|https://testanything.org/> output
+
+=item *
+
+leverages famous L<perl prove|http://search.cpan.org/perldoc?prove> and L<curl|http://curl.haxx.se/> utilities
 
 
 =item *
 
 has minimal dependency tree  and probably will run out of the box on most linux environments, provided that one has perl/bash/find/curl by hand ( which is true  for most cases )
 
-=item *
-
-has a simple and yet powerful DSL allow you to both run simple tests ( 200 OK ) or complicated ones ( using curl api and perl functions calls )
-
-=item *
-
-is daily it/devops/dev helper with low price mastering ( see my tutorial )
-
-=item *
-
-and yes ... swat is fun :)
-
 
 =back
 
@@ -345,7 +342,7 @@ Once swat is installed you have B<swat> command line tool to run swat tests, but
     mkdir -p my-app/hello # GET /hello
     mkdir -p my-app/hello/world # GET /hello/world
 
-    # define the content the expected to return by requested URIs
+    # define the content to return by URIs
 
     echo 200 OK >> my-app/hello/get.txt
     echo 200 OK >> my-app/hello/world/get.txt
@@ -377,7 +374,7 @@ When you give swat a run
 
     swat example/my-app 127.0.0.1
 
-It will find all the I<directories with get.txt|post.txt files inside> and "create" routes:
+It will find all the I<directories with get.txt or post.txt files inside> and "create" routes:
 
     GET hello/
     GET hello/world
@@ -388,11 +385,11 @@ When you are done with routes you need to set swat data.
 =head2 Swat data
 
 Swat data is DSL to describe/generate validation checks you apply to content returned from web application.
+
 Swat data is stored in swat data files, named get.txt or post.txt. 
 
 
-
-The process of validation looks like:
+The validation process looks like:
 
 =over
 
@@ -766,7 +763,7 @@ And finally apply settings from swat.ini file in route directory ( if any given
 
 =head1 TAP
 
-Swat produce output in L<TAP|https://testanything.org/> format , that means you may use your favorite tap parsers to bring result to
+Swat produces output in L<TAP|https://testanything.org/> format , that means you may use your favorite tap parsers to bring result to
 another test / reporting systems, follow TAP documentation to get more on this. Here is example for converting swat tests into JUNIT format
 
     swat $project_root $host --formatter TAP::Formatter::JUnit
@@ -778,7 +775,7 @@ See also L<"Prove settings"> section.
 
 Swat is shipped as cpan package, once it's installed ( see L</"Install swat"> section ) you have a command line tool called B<swat>, this is usage info on it:
 
-    swat project_dir URL <prove settings>
+    swat project_root_dir|swat_package URL <prove settings>
 
 =over
 
@@ -791,15 +788,13 @@ B<URL> - is base url for web application you run tests against, you need defined
 
 B<project_dir> - is a project root directory
 
+=item *
+
+B<swat_package> - the name of swat package, see L</"Swat Packages"> section
+
 
 =back
 
-=head1 Swat Packages
-
-Swat packages is distributable archives of swat tests. It's easy to create your own swat packages and share with other. 
-Consider https://github.com/melezhik/swat-packages project for details.
-
-
 
 =head1 Prove settings
 
@@ -816,10 +811,63 @@ C<-q -s> -  run tests in random and quite mode
 =back
 
 
-=head1 Debuggins
+=head1 Swat Packages
+
+Swat packages is distributable archives of swat tests. It's easy to create your own swat packages and share with other. 
+
+This is mini how-to on creating swat packages:
+
+=head2 Create swat package
+
+Let's imagine you've got ready swat tests you want to distribute. First of all you need to create _tar.gz archive_ of
+swat project root directory:
+
+    tar -zcf $project_root_dir.tar.gz project_root_dir
+
+For example for project ./examples/google 
+
+    cd ./examples/
+    tar -zcf google.tar.gz ./google
+
+=head2 Upload package to swat repository
+
+Swat repository might be  _ANY_ web server. One should upload archive into server.
+Let's say we have nginx server. The example below is for debian:
+
+    # install nginx:
+    sudo apt-get install nginx
+
+    # copy swat distributive:
+    sudo cp google.tar.gz /var/www/html/
+
+    # check for archive availability over web server:
+    curl -s 127.0.0.1/google.tar.gz -D - -o /dev/null  | head  -n 1
+    HTTP/1.1 200 OK
+
+You swat repository with nginx swat package uploaded is ready!
+
+=head2 Install swat package
+
+Swat comes with utility called B<swatman> to manage swat packages. 
+First of all one need to setup swat repository:
+
+    echo "swat_repo=127.0.0.1" >> ~/swat.ini
+
+Then install package
+
+    swatman install google
+
+=head2 Run swat tests
+
+Once swat package is installed into your system you man give it a run:
+
+    swat google google.ru
+
+=head1 Debugging
 
 set C<swat_debug> environmental variable to 1
 
+
 =head1 Examples
 
 ./examples directory contains examples of swat tests for different cases. Follow README.md files for details.
